"use strict";
/**
 * @license
 * Copyright 2019 Ludan Stoecklé
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConjugation = exports.getVerbInfo = void 0;
const spanish_verbs_1 = require("spanish-verbs");
function getVerbInfo(verb) {
    const verbInfo = {};
    for (const tense of spanish_verbs_1.validTenses) {
        verbInfo[tense] = {};
        const persons = [2, 5];
        for (const person of persons) {
            verbInfo[tense][person] = spanish_verbs_1.getConjugation(verb, tense, person);
        }
    }
    return verbInfo;
}
exports.getVerbInfo = getVerbInfo;
function getConjugation(verbsList, verb, tense, number) {
    if (!verb) {
        const err = new Error();
        err.name = 'TypeError';
        err.message = 'verb must not be null';
        throw err;
    }
    if (number != 'S' && number != 'P') {
        const err = new Error();
        err.name = 'TypeError';
        err.message = 'number must be S or P';
        throw err;
    }
    const person = number == 'S' ? 2 : 5;
    // must test validTenses list as is not included in browser packed packages
    if (!tense || (spanish_verbs_1.validTenses && spanish_verbs_1.validTenses.indexOf(tense)) === -1) {
        const err = new Error();
        err.name = 'TypeError';
        err.message = `tense must be ${spanish_verbs_1.validTenses.join()}`;
        throw err;
    }
    if (verbsList) {
        const verbInfo = verbsList[verb];
        if (!verbInfo) {
            const err = new Error();
            err.name = 'DictError';
            err.message = `verb ${verb} not found in list!`;
            throw err;
        }
        const verbInfoTense = verbInfo[tense];
        if (!verbInfoTense) {
            const err = new Error();
            err.name = 'DictError';
            err.message = `tense ${tense} not found for ${verb}: ${verbInfo}!`;
            throw err;
        }
        const conjugated = verbInfoTense[person];
        if (!conjugated) {
            const err = new Error();
            err.name = 'DictError';
            err.message = `person ${person} not found for ${verb}: ${conjugated}!`;
            throw err;
        }
        return conjugated;
    }
    else {
        return spanish_verbs_1.getConjugation(verb, tense, person);
    }
}
exports.getConjugation = getConjugation;
//# sourceMappingURL=index.js.map